@@ -1,4 +1,4 @@
-# $Id: custom.tcl 921 2007-02-11 10:27:18Z sergei $
+# $Id: custom.tcl 1373 2008-02-05 19:19:06Z sergei $
 
 option add *Customize.varforeground       blue widgetDefault
 option add *Customize.groupnameforeground blue widgetDefault
@@ -163,13 +163,9 @@ custom::defgroup Hidden "Hidden group" -group Tkabber -tag "Hidden group" \
 ###############################################################################
 
 proc custom::open_window {gid} {
-    global font
-
     set w .customize
     if {[winfo exists $w]} {
-	if {$::usetabbar} {
-	    .nb raise [::ifacetk::nbpage $w]
-	}
+	raise_win $w
 	goto $gid
 	focus $w.fields
 	return    
@@ -177,7 +173,8 @@ proc custom::open_window {gid} {
 
     add_win $w -title [::msgcat::mc "Customize"] \
 	-tabtitle [::msgcat::mc "Customize"] \
-	-class Customize
+	-class Customize \
+	-raise 1
 	#-raisecmd "focus [list $w.input]"
 
 
@@ -783,6 +780,8 @@ hook::add postload_hook custom::restore 60
 proc custom::update_page_offset {} {
     variable history
 
+    if {[llength $history(list)] == 0} return
+
     lassign [.customize.fields yview] offset
     lassign [lindex $history(list) $history(pos)] page
 
@@ -808,7 +807,8 @@ proc custom::history_move {shift} {
 
     lassign [lindex $history(list) $newpos] newgroup offset
     set history(pos) $newpos
-    
+    history_set_buttons
+
     set curgroup $newgroup
 
     fill_group .customize.fields $newgroup $offset
@@ -824,10 +824,27 @@ proc custom::history_add {gid} {
     
     lvarpush history(list) [list $gid 0]
     set history(pos) 0
+    history_set_buttons
 
     debugmsg custom [array get history]
 }
 
+proc custom::history_set_buttons {} {
+    variable history
+
+    if {$history(pos) == 0} {
+	.customize.navigate.forward configure -state disabled
+    } else {
+	.customize.navigate.forward configure -state normal
+    }
+
+    if {$history(pos) + 1 == [llength $history(list)]} {
+	.customize.navigate.back configure -state disabled
+    } else {
+	.customize.navigate.back configure -state normal
+    }
+}
+
 ##############################################################################
 
 proc custom::restore_window {gid args} {
