@@ -1,4 +1,4 @@
-# $Id: bwidget_workarounds.tcl 879 2007-01-18 21:37:19Z sergei $
+# $Id: bwidget_workarounds.tcl 1429 2008-05-18 12:36:02Z sergei $
 
 ##########################################################################
 auto_load Button
@@ -205,7 +205,7 @@ if {0 && [info tclversion] >= 8.5} {
 
     proc PanedWin {path args} {
 	if {[catch {
-		 eval [list PanedWindow $path] $args -activator button
+		 eval [list PanedWindow $path] $args -activator line
 	     } res]} {
 	    return [eval [list PanedWindow $path] $args]
 	} else {
@@ -214,7 +214,32 @@ if {0 && [info tclversion] >= 8.5} {
     }
 
     proc PanedWinAdd {path args} {
-	return [eval [list $path add] $args]
+	set res [eval [list $path add] $args]
+	catch {
+	    set activator [Widget::getoption $path -activator]
+	    if {$activator == ""} {
+		if { $::tcl_platform(platform) != "windows" } {
+		    set activator button
+		} else {
+		    set activator line
+		}
+	    }
+
+	    if {$activator == "line"} {
+		set side [Widget::getoption $path -side]
+		set num $PanedWindow::_panedw($path,nbpanes)
+		incr num -1
+		if {$num > 0} {
+		    $path.sash$num.sep configure -relief flat
+		    if {$side == "top" || $side == "bottom"} {
+			place configure $path.sash$num.sep -width 4
+		    } else {
+			place configure $path.sash$num.sep -height 4
+		    }
+		}
+	    }
+	}
+	return $res
     }
 
     proc PanedWinConf {path index args} {
@@ -319,4 +344,34 @@ if {($::tcl_platform(platform) != "unix") || ($::aquaP)} {
 proc BWidget::bindMouseWheel {widget} {}
 
 ##########################################################################
+auto_load Dialog
+
+rename Dialog::create Dialog::create:old
+
+proc Dialog::create {path args} {
+    toplevel $path
+    wm withdraw $path
+    set parent [winfo parent $path]
+    destroy $path
+    set transient 1
+    set newargs {}
+    foreach {key val} $args {
+	switch -- $key {
+	    -parent { set parent $val ; lappend newargs -parent $val }
+	    -transient { set transient $val }
+	    default { lappend newargs $key $val }
+	}
+    }
+    # Do not make a dialog window transient if its parent isn't vewable.
+    # Otherwise it leads to hang of a whole application.
+    if {$parent == ""} {
+	set parent .
+    }
+    if {![winfo viewable [winfo toplevel $parent]] } {
+	set transient 0
+    }
+    eval {Dialog::create:old $path -transient $transient} $newargs
+}
+
+##########################################################################
 
