@@ -1,4 +1,4 @@
-# $Id: ilogin.tcl 677 2006-03-28 19:12:17Z aleksey $
+# $Id: ilogin.tcl 1220 2007-09-04 12:14:02Z sergei $
 
 proc update_login_entries {l {i 0}} {
     global ltmp
@@ -8,7 +8,7 @@ proc update_login_entries {l {i 0}} {
 	array set loginconf [array get ltmp]
     }
     foreach ent {username server port password resource priority \
-            altserver httpproxy httpproxyport httplogin httppassword \
+            altserver proxyhost proxyport proxyusername proxypassword \
             sslcertfile pollurl} {
         if {[winfo exists $l.$ent]} {
             catch { $l.$ent icursor end }
@@ -19,8 +19,7 @@ proc update_login_entries {l {i 0}} {
 			{dontusessl usecompress legacyssl encrypted \
 			 sslcertfile lsslcertfile bsslcertfile} \
             usealtserver {altserver laltserver port lport} {} \
-            useproxy {httpproxy httpproxyport httplogin httppassword \
-            lhttpproxy lhttpproxyport lhttplogin lhttppassword} {} \
+	    usesasl {allowgoogletoken} {} \
 	    } {
         if {![info exists ltmp($check)] || ![winfo exists $l.$check]} {
             continue
@@ -50,6 +49,22 @@ proc update_login_entries {l {i 0}} {
 	    }
 	}
     }
+    catch {
+	if {[cequal $ltmp(proxy) none]} {
+	    foreach ent {proxyhost proxyport proxyusername proxypassword \
+			 lproxyhost lproxyport lproxyusername lproxypassword} {
+		$l.$ent configure -state disabled
+                if {[cequal [focus] $l.$ent]} {
+                    focus [Widget::focusPrev $l.$ent]
+                }
+	    }
+	} else {
+	    foreach ent {proxyhost proxyport proxyusername proxypassword \
+			 lproxyhost lproxyport lproxyusername lproxypassword} {
+		$l.$ent configure -state normal
+	    }
+	}
+    }
     catch {
 	if {![cequal [$l.dontusessl cget -state] disabled] && \
 		($ltmp(stream_options) == "ssl" || \
@@ -187,6 +202,13 @@ proc login_dialog {} {
 	    -command [list [namespace current]::update_login_entries $l]
 
 	grid $l.usesasl -row 1 -column 0 -sticky w -in $auth_page
+
+	checkbutton $l.allowgoogletoken \
+	    -text [::msgcat::mc "Allow X-GOOGLE-TOKEN SASL mechanism"] \
+	    -variable ltmp(allowgoogletoken) \
+	    -command [list [namespace current]::update_login_entries $l]
+
+	grid $l.allowgoogletoken -row 2 -column 0 -sticky w -in $auth_page
     }
 
     grid columnconfigure $auth_page 0 -weight 1
@@ -217,7 +239,7 @@ proc login_dialog {} {
 	    radiobutton $l.legacyssl -text [::msgcat::mc "Encryption (legacy SSL)"] \
 		-variable ltmp(stream_options) -value ssl \
 		-command [list [namespace current]::update_login_entries $l]
-	    label $l.lsslcertfile -text [::msgcat::mc "SSL Certificate:"]
+	    label $l.lsslcertfile -text [::msgcat::mc "SSL certificate:"]
 	    entry $l.sslcertfile -textvariable ltmp(sslcertfile)
 	    button $l.bsslcertfile -text [::msgcat::mc "Browse..."] \
 		-command [list eval set ltmp(sslcertfile) {[tk_getOpenFile]}]
@@ -266,30 +288,60 @@ proc login_dialog {} {
     if {$have_proxy} {
 	set proxy_page [$nb insert end proxy_page -text [::msgcat::mc "Proxy"]]
 
-	checkbutton $l.useproxy -text [::msgcat::mc "Use Proxy"] \
-	    -variable ltmp(useproxy) \
-	    -command [list [namespace current]::update_login_entries $l]
-	grid $l.useproxy -row 0 -column 0 -sticky w -columnspan 3 -in $proxy_page
+	label $l.lproxy -text [::msgcat::mc "Proxy type:"]
+	grid $l.lproxy -row 0 -column 0 -sticky e -in $proxy_page
+	frame $l.proxy
+	grid $l.proxy -row 0 -column 1 -columnspan 3 -sticky w -in $proxy_page
 
-	label $l.lhttpproxy -text [::msgcat::mc "Proxy Server:"]
-	entry $l.httpproxy -textvariable ltmp(httpproxy)
-	label $l.lhttpproxyport -text [::msgcat::mc "Proxy Port:"]
-	Spinbox $l.httpproxyport 0 65535 1 ltmp(httpproxyport)
+	set col 0
+	foreach type [jlib::capabilities proxy] {
+	    switch -- $type {
+		none {
+		   radiobutton $l.proxy.none -text [::msgcat::mc "None"] \
+			-variable ltmp(proxy) -value none \
+			-command [list [namespace current]::update_login_entries $l]
+		    grid $l.proxy.none -row 0 -column [incr col] -sticky w
+		}
+		socks4 {
+		   radiobutton $l.proxy.socks4 -text [::msgcat::mc "SOCKS4a"] \
+			-variable ltmp(proxy) -value socks4 \
+			-command [list [namespace current]::update_login_entries $l]
+		    grid $l.proxy.socks4 -row 0 -column [incr col] -sticky w
+		}
+		socks5 {
+		   radiobutton $l.proxy.socks5 -text [::msgcat::mc "SOCKS5"] \
+			-variable ltmp(proxy) -value socks5 \
+			-command [list [namespace current]::update_login_entries $l]
+		    grid $l.proxy.socks5 -row 0 -column [incr col] -sticky w
+		}
+		https {
+		   radiobutton $l.proxy.https -text [::msgcat::mc "HTTPS"] \
+			-variable ltmp(proxy) -value https \
+			-command [list [namespace current]::update_login_entries $l]
+		    grid $l.proxy.https -row 0 -column [incr col] -sticky w
+		}
+	    }
+	}
 
-	grid $l.lhttpproxy     -row 1 -column 0 -sticky e -in $proxy_page
-	grid $l.httpproxy      -row 1 -column 1 -sticky ew -in $proxy_page
-	grid $l.lhttpproxyport -row 1 -column 2 -sticky e -in $proxy_page
-	grid $l.httpproxyport  -row 1 -column 3 -sticky ew -in $proxy_page
+	label $l.lproxyhost -text [::msgcat::mc "Proxy server:"]
+	entry $l.proxyhost -textvariable ltmp(proxyhost)
+	label $l.lproxyport -text [::msgcat::mc "Proxy port:"]
+	Spinbox $l.proxyport 0 65535 1 ltmp(proxyport)
 
-	label $l.lhttplogin -text [::msgcat::mc "Proxy Login:"]
-	ecursor_entry [entry $l.httplogin -textvariable ltmp(httplogin)]
-	label $l.lhttppassword -text [::msgcat::mc "Proxy Password:"]
-	ecursor_entry [entry $l.httppassword -show * -textvariable ltmp(httppassword)]
+	grid $l.lproxyhost     -row 1 -column 0 -sticky e -in $proxy_page
+	grid $l.proxyhost      -row 1 -column 1 -sticky ew -in $proxy_page
+	grid $l.lproxyport -row 1 -column 2 -sticky e -in $proxy_page
+	grid $l.proxyport  -row 1 -column 3 -sticky ew -in $proxy_page
 
-	grid $l.lhttplogin    -row 2 -column 0 -sticky e -in $proxy_page
-	grid $l.httplogin     -row 2 -column 1 -sticky ew -in $proxy_page
-	grid $l.lhttppassword -row 2 -column 2 -sticky e -in $proxy_page
-	grid $l.httppassword  -row 2 -column 3 -sticky ew -in $proxy_page
+	label $l.lproxyusername -text [::msgcat::mc "Proxy username:"]
+	ecursor_entry [entry $l.proxyusername -textvariable ltmp(proxyusername)]
+	label $l.lproxypassword -text [::msgcat::mc "Proxy password:"]
+	ecursor_entry [entry $l.proxypassword -show * -textvariable ltmp(proxypassword)]
+
+	grid $l.lproxyusername    -row 2 -column 0 -sticky e -in $proxy_page
+	grid $l.proxyusername     -row 2 -column 1 -sticky ew -in $proxy_page
+	grid $l.lproxypassword -row 2 -column 2 -sticky e -in $proxy_page
+	grid $l.proxypassword  -row 2 -column 3 -sticky ew -in $proxy_page
 
 	grid columnconfigure $proxy_page 1 -weight 3
 	grid columnconfigure $proxy_page 2 -weight 1
