@@ -1,4 +1,4 @@
-# $Id: iroster.tcl 1430 2008-05-18 13:21:52Z sergei $
+# $Id: iroster.tcl 1506 2008-10-10 20:08:57Z sergei $
 
 Tree .faketree
 foreach {k v} [list background       White \
@@ -178,7 +178,7 @@ proc roster::set_group_lists {connid} {
 	if {$options(nested)} {
 	    set tmp {}
 	    foreach group $groups {
-		set tmp1 [::textutil::splitx $group $options(nested_delimiter)]
+		set tmp1 [msplit $group $options(nested_delimiter)]
 		for {set i 0} {$i < [llength $tmp1]} {incr i} {
 		    lappend tmp [lrange $tmp1 0 $i]
 		}
@@ -388,7 +388,7 @@ proc roster::redraw {} {
 	    if {![lempty $jid_groups]} {
 		foreach group $jid_groups {
 		    if {$options(nested)} {
-			set sgroup [::textutil::splitx $group $options(nested_delimiter)]
+			set sgroup [msplit $group $options(nested_delimiter)]
 		    } else {
 			set sgroup [list $group]
 		    }
@@ -529,6 +529,7 @@ proc roster::redraw {} {
 	    }
 	    if {!$show_only_online || $show_offline_group || \
 		    $roster(show_offline,$gid) || \
+		    ($options(use_filter) && $options(filter) != "") || \
 		    $online + $not_users + $sub_jids > 0} {
 		if {$users} {
 		    addline .roster group "$group_name ($online/$users)" \
@@ -555,6 +556,7 @@ proc roster::redraw {} {
 		    }
 		    set cjid [list $connid $jid]
 		    if {!$show_only_online || $show_offline_users || $roster(show_offline,$gid) || \
+			    ($options(use_filter) && $options(filter) != "") || \
 			    ![info exists useronline($jid)] || $useronline($jid)} {
 			lassign [::roster::get_category_and_subtype $connid $jid] category type
 			set jids [get_jids_of_user $connid $jid]
@@ -1764,7 +1766,7 @@ proc roster::create_group_popup_menu {connid name} {
 	destroy $m
     }
     if {$options(nested)} {
-	set oname [::textutil::splitx $name $options(nested_delimiter)]
+	set oname [msplit $name $options(nested_delimiter)]
     } else {
 	set oname $name
     }
