@@ -1,4 +1,4 @@
-# $Id: login.tcl 1442 2008-05-21 11:36:30Z sergei $
+# $Id: login.tcl 1503 2008-09-25 19:08:54Z sergei $
 
 
 if {[lcontain [jlib::capabilities transport] tls]} {
@@ -362,13 +362,17 @@ proc login_connect {logindata} {
 	lappend args -usesasl $lc(usesasl)
     }
 
-    if {$have_proxy && ($lc(proxy) != "none")} {
-	lappend args -proxy $lc(proxy)
-	lappend args -proxyhost $lc(proxyhost)
-	lappend args -proxyport $lc(proxyport)
-	lappend args -proxyusername $lc(proxyusername)
-	lappend args -proxypassword $lc(proxypassword)
-	lappend args -proxyuseragent $lc(proxyuseragent)
+    if {$have_proxy} {
+	if {($lc(proxy) != "none")} {
+	    lappend args -proxy $lc(proxy)
+	    lappend args -proxyhost $lc(proxyhost)
+	    lappend args -proxyport $lc(proxyport)
+	    lappend args -proxyusername $lc(proxyusername)
+	    lappend args -proxypassword $lc(proxypassword)
+	    lappend args -proxyuseragent $lc(proxyuseragent)
+	} else {
+	    lappend args -proxy ""
+	}
     }
 
     set ascii_server [idna::domain_toascii $lc(server)]
@@ -467,23 +471,22 @@ proc logout {{connid {}}} {
     global reconnect_retries
     global login_after_id
 
+    debugmsg login "LOGOUT $connid"
+
     # TODO
     foreach user [array names login_after_id] {
 	after cancel $login_after_id($user)
 	unset login_after_id($user)
     }
 
-    hook::run predisconnected_hook $connid
-
-    jlib::disconnect $connid
     if {$connid == {}} {
-	roster::clean
+	foreach connid [jlib::connections] {
+	    disconnected $connid
+	}
     } else {
-	roster::clean_connection $connid
+	disconnected $connid
     }
 
-    disconnected $connid
-
     set reconnect_retries 0
 }
 
@@ -498,15 +501,6 @@ proc client:reconnect {connid} {
 
     debugmsg login "RECONNECT $connid"
 
-    hook::run predisconnected_hook $connid
-
-    jlib::disconnect $connid
-    roster::clean_connection $connid
-
-    if {[jlib::connections] == {}} {
-	set_status "Disconnected"
-    }
-
     disconnected $connid
 
     if {[incr reconnect_retries] <= 3} {
@@ -522,11 +516,19 @@ proc connected {connid logindata} {
 proc disconnected {connid} {
     global curuserstatus userstatusdesc
 
+    hook::run predisconnected_hook $connid
+
+    jlib::disconnect $connid
+    roster::clean_connection $connid
+
     if {[jlib::connections] == {}} {
+	set_status "Disconnected"
+
 	set curuserstatus unavailable
 	set userstatusdesc [::msgcat::mc "Not logged in"]
 	hook::run change_our_presence_post_hook unavailable
     }
+
     hook::run disconnected_hook $connid
 }
 
@@ -571,7 +573,7 @@ proc recv_auth_result {connid logindata res args} {
 
 proc recv_register_result {connid logindata res args} {
     if {$res == "OK"} {
-	jlib::disconnect
+	jlib::disconnect $connid
 	login $logindata
     } else {
 	if {[winfo exists .auth_err$connid]} {
