@@ -1,4 +1,4 @@
-# $Id: muc.tcl 1408 2008-05-11 11:29:45Z sergei $
+# $Id: muc.tcl 1512 2008-10-11 13:08:59Z sergei $
 
 # Multi-User Chat support (XEP-0045)
 
@@ -141,6 +141,10 @@ proc muc::add_conference_menu_items {m chatid idx args} {
     trace vdelete ::muc::muc_compatible($group) w \
 	[list muc::add_conference_menu_items $m $chatid $idx]
 
+    add_muc_menu_items $m $chatid $idx
+}
+
+proc muc::add_muc_menu_items {m chatid idx} {
     set mm [menu $m.muc -tearoff 0]
 
     $mm add command -label [::msgcat::mc "Configure room"] \
@@ -164,6 +168,47 @@ proc muc::add_conference_menu_items {m chatid idx args} {
     $m insert $idx cascade -label [::msgcat::mc "MUC"] -menu $mm
 }
 
+proc muc::disco_node_menu_setup {m bw tnode data parentdata} {
+    lassign $data type connid jid node
+    lassign $parentdata ptype pconnid pjid pnode
+    switch -- $type {
+	item {
+	    set identities [disco::get_jid_identities $connid $jid $node]
+	    set pidentities [disco::get_jid_identities $pconnid $pjid $pnode]
+
+	    set features [disco::get_jid_features $connid $jid $node]
+	    set pfeatures [disco::get_jid_features $pconnid $pjid $pnode]
+
+	    # JID with resource is not a room JID
+	    if {[node_and_server_from_jid $jid] != $jid} return
+
+	    # A room must have non-empty node
+	    if {[node_from_jid $jid] == ""} return
+
+	    if {[lempty $identities]} {
+		set identities $pidentities
+	    }
+
+	    if {[lempty $features]} {
+		set features $pfeatures
+	    }
+
+	    foreach id $identities {
+		if {[jlib::wrapper:getattr $id category] == "conference"} {
+		    foreach f $features {
+			if {[jlib::wrapper:getattr $f var] == $::NS(muc)} {
+			    add_muc_menu_items $m [chat::chatid $connid $jid] end
+			    return
+			}
+		    }
+		}
+	    }
+	}
+    }
+}
+
+hook::add disco_node_menu_hook muc::disco_node_menu_setup 60
+
 ###############################################################################
 
 proc muc::handle_commands {chatid user body type} {
@@ -1348,11 +1393,30 @@ proc muc::request_negotiation {connid group} {
     disco::request_info [server_from_jid $group] "" \
 	-connection $connid \
 	-cache yes \
-	-handler [list muc::recv_negotiation $group]
+	-handler [list muc::recv_negotiation1 $connid $group]
 }
 
 
-proc muc::recv_negotiation {group res identities features extras} {
+proc muc::recv_negotiation1 {connid group res identities features extras} {
+    variable muc_compatible
+
+    if {[cequal $res OK]} {
+	foreach f $features {
+	    set var [jlib::wrapper:getattr $f var]
+	    if {$var == $::NS(muc)} {
+		set muc_compatible($group) 1
+		return
+	    }
+	}
+    }
+
+    disco::request_info $group "" \
+	-connection $connid \
+	-cache yes \
+	-handler [list muc::recv_negotiation2 $group]
+}
+
+proc muc::recv_negotiation2 {group res identities features extras} {
     variable muc_compatible
 
     if {[cequal $res OK]} {
