@@ -1,4 +1,4 @@
-# $Id: plugins.tcl 828 2006-12-15 20:58:11Z sergei $
+# $Id: plugins.tcl 1198 2007-08-18 09:53:35Z sergei $
 
 namespace eval plugins {}
 
@@ -11,7 +11,7 @@ proc plugins::load {dir args} {
 	}
     }
 
-    foreach file [glob -nocomplain $dir/*.tcl] {
+    foreach file [lsort [glob -nocomplain $dir/*.tcl]] {
 	debugmsg plugins "Loading plugin from $file"
 	if {$uplev} {
 	    uplevel [list source $file]
