@@ -1,10 +1,9 @@
-# $Id: draw_info.tcl,v 1.2 2003/11/04 20:58:55 aleksey Exp $
+# $Id: draw_info.tcl 882 2007-01-26 17:55:57Z sergei $
 
 proc handle_info {chatid from type body x} {
 
     if {[cequal $type info]} {
-	chat::add_emoteiconed_text [chat::chat_win $chatid] $body info
-	tab_set_updated [chat::winid $chatid] 1 info
+	::richtext::render_message [chat::chat_win $chatid] $body info
 	return stop
     }
 }
