@@ -1,4 +1,4 @@
-# $Id: histool.tcl 1084 2007-04-08 11:06:32Z sergei $
+# $Id: histool.tcl 1397 2008-03-23 08:04:51Z sergei $
 # History tool -- allows browsing and searching through Tkabber chat logs.
 
 option add *ChatHistory.geometry          "640x480" widgetDefault
@@ -26,7 +26,11 @@ proc histool::on_init {} {
 
 proc histool::browse args {
     if {[is_unsupported]} {
-	tk_messageBox -message [::msgcat::mc "Unsupported log dir format"]
+	NonmodalMessageDlg [epath] \
+		-aspect 50000 \
+		-icon error \
+		-title [::msgcat::mc "Error"] \
+		-message [::msgcat::mc "Unsupported log dir format"]
 	return
     }
 
@@ -40,14 +44,13 @@ proc histool::browse args {
 }
 
 proc histool::browser_create {w} {
-    global font tk_relief tk_borderwidth
-
     variable loghier [get_log_hier]
 
     add_win $w \
 	    -title [::msgcat::mc "Chats History"] \
 	    -tabtitle [::msgcat::mc "Chats history"] \
-	    -class ChatHistory
+	    -class ChatHistory \
+	    -raise 1
 
     bind $w <Destroy> +[list [namespace current]::browser_cleanup [double% $w] %W]
 
@@ -171,14 +174,15 @@ proc histool::ltree_create {w} {
 
     [namespace parent]::search::browser::setup_panel $w $sw $t
 
+    set counter 0
     foreach LA [lsort -index 0 $loghier] {
 	lassign $LA year months
 	$t insert end root root.$year -text $year
 	foreach LB [lsort -index 0 $months] {
 	    lassign $LB month jids
 	    $t insert end root.$year root.$year.$month -text $d2m($month)
-	    foreach {jid fname} [sort_jids $jids -order {server node resource}] {
-		$t insert end root.$year.$month root.$year.$month.$jid -text $jid
+	    foreach jid [sort_jids $jids -order {server node resource}] {
+		$t insert end root.$year.$month [incr counter] -text $jid
 	    }
 	}
     }
@@ -420,17 +424,18 @@ proc histool::ftsearch_grep_msg {"of" slist "for" what "from" chan} {
 
     if {![eof $chan]} {
 	set msg [::logger::log_to_str $line]
-	array set mparts $msg
-	foreach part {nick body} {
-	    if {[info exists mparts($part)]
-	    && [::plugins::search::match $what $mparts($part)]} {
-		lassign [lindex $slist end] year month jid
-		set r $ftsearch(results)
-		$r configure -state normal
-		ftsearch_render_msg $r $year $month $jid $msg
-		$r configure -state disabled
-		set ftsearch(found) 1
-		break
+	if {![catch {array set mparts $msg}]} {
+	    foreach part {nick body} {
+		if {[info exists mparts($part)] && \
+			[::plugins::search::match $what $mparts($part)]} {
+		    lassign [lindex $slist end] year month jid
+		    set r $ftsearch(results)
+		    $r configure -state normal
+		    ftsearch_render_msg $r $year $month $jid $msg
+		    $r configure -state disabled
+		    set ftsearch(found) 1
+		    break
+		}
 	    }
 	}
 	schedule \
@@ -455,7 +460,7 @@ proc histool::ftsearch_render_msg {t year month jid msg} {
 
     set mynick [get_group_nick $jid ""]
 
-    array set mparts $msg
+    if {[catch {array set mparts $msg}]} return
 
     set start [$t index {end - 1 char}]
 
