@@ -1,4 +1,4 @@
-# $Id: rawxml.tcl 927 2007-02-11 13:37:04Z sergei $
+# $Id: rawxml.tcl 1429 2008-05-18 12:36:02Z sergei $
 
 option add *RawXML.inforeground       DarkRed     widgetDefault
 option add *RawXML.outforeground      DarkBlue    widgetDefault
@@ -101,28 +101,40 @@ proc rawxml::handle_inout_x {connid xml prefix tag} {
     $dump configure -state disabled
 }
 
-proc rawxml::pretty_print {t xmldata prefix tag} {
-    global font
+proc rawxml::pretty_print {t xmldata prefix tag {xmlns jabber:client}} {
     variable options
     variable tabs
 
     jlib::wrapper:splitxml $xmldata tagname vars isempty chdata subtags
 
+    set vars1 {}
+    foreach {attr value} $vars {
+	if {$attr == "xmlns"} {
+	    if {$value == $xmlns} {
+		continue
+	    } else {
+		set xmlns $value
+	    }
+	}
+	lappend vars1 $attr $value
+    }
+
     $t insert end "$prefix<" {} $tagname ${tag}tag
-    if {[llength $vars] != 0} {
+    if {[llength $vars1] != 0} {
 	#set attrprefix ${prefix}[string repeat " " \
 	#			     [expr {[clength $tagname] + 2}]]
 	set arr_index "$prefix<$tagname "
 	if {![info exists tabs($arr_index)]} {
-	    set tabs($arr_index) [font measure $font $arr_index]
+	    set tabs($arr_index) [font measure [$t cget -font] $arr_index]
 	}
 	$t tag configure $arr_index -tabs [list $tabs($arr_index)]
-	set vars1 [lassign $vars attr value]
+
+	set vars2 [lassign $vars1 attr value]
 	$t insert end \
 	    " $attr" ${tag}attr \
 	    "=" {} \
 	    "'[jlib::wrapper:xmlcrypt $value]'" ${tag}value
-	foreach {attr value} $vars1 {
+	foreach {attr value} $vars2 {
 	    $t insert end \
 		"\n\t$attr" [list ${tag}attr $arr_index]\
 		"=" {} \
@@ -143,7 +155,8 @@ proc rawxml::pretty_print {t xmldata prefix tag} {
 	$t insert end "\n"
         foreach subdata $subtags {
 	    pretty_print $t $subdata \
-		$prefix[string repeat " " $options(indent)] $tag
+		$prefix[string repeat " " $options(indent)] $tag \
+		$xmlns
 	}
 	$t insert end "$prefix</" {} $tagname ${tag}tag ">\n"
     }
@@ -159,8 +172,6 @@ proc ::LOG_OUTPUT_XML {connid x} \
     "[namespace current]::rawxml::handle_inout_x \$connid \$x OUT out"
 
 proc rawxml::open_window {} {
-    global font
-
     set w .rawxml
     if {[winfo exists $w]} {
 	return
@@ -169,7 +180,8 @@ proc rawxml::open_window {} {
     add_win $w -title [::msgcat::mc "Raw XML"] \
 	-tabtitle [::msgcat::mc "Raw XML"] \
 	-class RawXML \
-	-raisecmd [list focus $w.input]
+	-raisecmd [list focus $w.input] \
+	-raise 1
 
 
     set tools [frame $w.tools]
@@ -193,7 +205,7 @@ proc rawxml::open_window {} {
         "
     pack $tools.clear -side left -anchor w
 
-    PanedWin $w.pw -side right -pad 0 -width 8
+    PanedWin $w.pw -side right -pad 0 -width 4
     pack $w.pw -fill both -expand yes
 
     set uw [PanedWinAdd $w.pw -weight 1 -minsize 100]
@@ -202,14 +214,14 @@ proc rawxml::open_window {} {
 
     set isw [ScrolledWindow $w.isw -scrollbar vertical]
     pack $isw -side bottom -fill both -expand yes -in $dw
-    set input [textUndoable $w.input -font $font \
+    set input [textUndoable $w.input \
 		   -height [option get $w inputheight RawXML]]
     $isw setwidget $input
     [winfo parent $dw] configure -height [winfo reqheight $input]
 
     set sw [ScrolledWindow $w.sw -scrollbar vertical]
     pack $sw -side top -fill both -expand yes -in $uw
-    set dump [text $w.dump -font $font]
+    set dump [text $w.dump]
     $sw setwidget $dump
 
     $dump configure -state disabled
@@ -290,7 +302,12 @@ proc rawxml::send_xml {} {
     lvarpush history(stack) $xml 1
     set history(pos) 0
 
-    jlib::outmsg $xml
+    if {[llength [::jlib::connections]] == 0} {
+	return -code error [::msgcat::mc "Not connected"]
+    } else {
+	set connid [lindex [::jlib::connections] 0]
+	jlib::outmsg $xml -connection $connid
+    }
     $input delete 1.0 end
 }
 
@@ -476,3 +493,4 @@ proc rawxml::save_session {vsession} {
 
 hook::add save_session_hook [namespace current]::rawxml::save_session
 
+# vim:ts=8:sw=4:sts=4:noet
