@@ -1,4 +1,4 @@
-# $Id: sound.tcl 903 2007-02-07 19:31:31Z sergei $
+# $Id: sound.tcl 1514 2008-10-17 08:24:36Z sergei $
 
 namespace eval ::sound {
 
@@ -36,11 +36,10 @@ The Snack package is available at http://www.speech.kth.se/snack/index.html"
     custom::defvar options(mute_if_focus) 0 \
 	[::msgcat::mc "Mute sound if Tkabber window is focused."] \
 	-type boolean -group Sound
-# One could use external play program instead of Snack (default for unix)
-    custom::defvar options(external_play_program) \
-	[expr {($::tcl_platform(platform) == "unix" && !$vfs) ? "esdplay" : ""}] \
+    # One could use external play program instead of Snack
+    custom::defvar options(external_play_program) "" \
 	[::msgcat::mc "External program, which is to be executed to play sound.\
-If empty, Snack library is used (if available) to play sound."] \
+		       If empty, Snack library is used (if available) to play sound."] \
 	-type string -group Sound
     # Params for external play program
     custom::defvar options(external_play_program_options) "" \
@@ -52,6 +51,11 @@ If empty, Snack library is used (if available) to play sound."] \
 	[::msgcat::mc "Sound to play when connected to Jabber server."] \
 	-command [list [namespace current]::load_sound_file connected] \
 	-type file -group Sound
+    custom::defvar options(disconnected_sound) \
+	[fullpath sounds default disconnected.wav] \
+	[::msgcat::mc "Sound to play when disconnected from Jabber server."] \
+	-command [list [namespace current]::load_sound_file disconnected] \
+	-type file -group Sound
     custom::defvar options(presence_available_sound) \
 	[fullpath sounds default presence_available.wav] \
 	[::msgcat::mc "Sound to play when available presence is received."] \
@@ -63,7 +67,7 @@ If empty, Snack library is used (if available) to play sound."] \
 	-command [list [namespace current]::load_sound_file presence_unavailable] \
 	-type file -group Sound
     custom::defvar options(chat_my_message_sound) \
-	"" \
+	[fullpath sounds default chat_my_message.wav] \
 	[::msgcat::mc "Sound to play when sending personal chat message."] \
 	-command [list [namespace current]::load_sound_file chat_my_message] \
 	-type file -group Sound
@@ -78,7 +82,7 @@ If empty, Snack library is used (if available) to play sound."] \
 	-command [list [namespace current]::load_sound_file groupchat_server_message] \
 	-type file -group Sound
     custom::defvar options(groupchat_my_message_sound) \
-	"" \
+	[fullpath sounds default groupchat_my_message.wav] \
 	[::msgcat::mc "Sound to play when groupchat message from me is received."] \
 	-command [list [namespace current]::load_sound_file groupchat_my_message] \
 	-type file -group Sound
@@ -107,6 +111,7 @@ groupchat message is received."] \
 	[namespace current]::presence_notify 100
     hook::add change_our_presence_post_hook [namespace current]::mute_setup 100
     hook::add connected_hook [namespace current]::connected_notify 100
+    hook::add predisconnected_hook [namespace current]::disconnected_notify 100
     hook::add postload_hook [namespace current]::sound_setup 100
     hook::add draw_message_hook [namespace current]::chat_message_notify 19
 }
@@ -155,7 +160,7 @@ proc ::sound::sound_setup {} {
 
     foreach name [list groupchat_server_message groupchat_my_message \
 		       groupchat_their_message chat_my_message \
-		       chat_their_message connected \
+		       chat_their_message connected disconnected \
 		       presence_available presence_unavailable \
 		       groupchat_their_message_to_me] {
 	load_sound_file $name
@@ -284,7 +289,7 @@ proc ::sound::mute_setup {status} {
     }
 }
 
-proc ::sound::connected_notify {args} {
+proc ::sound::connected_notify {connid} {
     variable options
     variable sounds
 
@@ -293,6 +298,23 @@ proc ::sound::connected_notify {args} {
     play $sounds(connected) 1
 }
 
+proc ::sound::disconnected_notify {connid} {
+    variable options
+    variable sounds
+
+    if {[is_mute]} return
+
+    if {$connid == {}} {
+	if {[llength [jlib::connections]] > 0} {
+	    play $sounds(disconnected) 1
+	}
+    } else {
+	if {[lsearch -exact [jlib::connections] $connid] >= 0} {
+	    play $sounds(disconnected) 1
+	}
+    }
+}
+
 proc ::sound::is_mute {} {
     variable snack
     variable options
