@@ -1,17 +1,8 @@
-# $Id: browse.tcl 722 2006-09-18 21:01:30Z sergei $
-
-proc iq_browse {connid from lang child} {
-    browser::parse_items $from $child
-
-    return {}
-}
-
-iq::register_handler set {} jabber:iq:browse \
-    [namespace current]::iq_browse
+# $Id: browse.tcl 1203 2007-08-30 16:56:14Z sergei $
 
 proc iq_browse_reply {connid from lang child} {
     set restags {}
-    foreach ns $::iq::supported_ns {
+    foreach ns [lsort $::iq::supported_ns] {
 	lappend restags [jlib::wrapper:createtag ns \
 			     -chdata $ns]
     }
