@@ -1,4 +1,4 @@
-# $Id: time2.tcl 1440 2008-05-20 17:51:38Z sergei $
+# $Id: time2.tcl 1461 2008-06-15 19:45:10Z sergei $
 # Replies to XEP-0202 (Entity Time) queries
 
 custom::defvar options(reply_xmpp_time) 1 \
@@ -22,7 +22,7 @@ proc xmpp_time {connid from lang child} {
 	      [jlib::wrapper:createtag tzo \
 		   -chdata [timezone_offset]]]
     
-    set res [jlib::wrapper:createtag query \
+    set res [jlib::wrapper:createtag time \
 		 -vars {xmlns urn:xmpp:time} \
 		 -subtags $restags]
     
@@ -43,6 +43,6 @@ proc timezone_offset {} {
     return $S$H:$M
 }
 
-iq::register_handler get query urn:xmpp:time \
+iq::register_handler get time urn:xmpp:time \
     [namespace current]::xmpp_time
 
