@@ -1,4 +1,4 @@
-# $Id: wmdock.tcl,v 1.7 2006/02/09 20:08:51 aleksey Exp $
+# $Id: wmdock.tcl 894 2007-01-31 07:36:17Z sergei $
 
 if {![cequal $::interface tk]} return
 
@@ -7,7 +7,7 @@ if {![info exists ::wmaker_dock] || !$::wmaker_dock} {
 }
 
 namespace eval ::wmdock {
-    set save_status ""
+    set save_status unavailable
     set balloon_msg ""
     set msgs 0
     array set msgsc {}
@@ -40,7 +40,18 @@ proc ::wmdock::msg_recv {chatid from type body x} {
     if {[chat::is_our_jid $chatid $from] || ![cequal $type chat]} {
 	return
     }
-    
+
+    foreach xelem $x {
+	jlib::wrapper:splitxml $xelem tag vars isempty chdata children
+	
+	# Don't count message if this 'empty' tag is present. It indicates
+	# messages history in chat window.
+	if {[cequal $tag ""] && \
+		[cequal [jlib::wrapper:getattr $vars xmlns] tkabber:x:nolog]} {
+	    return
+	}
+    }
+
     set cw [chat::winid $chatid]
     set page [crange [win_id tab $cw] 1 end]
     if {$::usetabbar && $page != [.nb raise]} {
@@ -55,7 +66,7 @@ proc ::wmdock::msg_recv {chatid from type body x} {
     set balloon_msg [format [::msgcat::mc "Message from %s"] $from]
     
     after cancel $msg_afterid
-    .icon.c itemconfigure icon -image browser/message
+    .icon.c itemconfigure icon -image docking/message
     .icon.c itemconfigure text -text [format [::msgcat::mc "%s msgs"] $msgs]
     
     set msg_afterid [after 5000 ::wmdock::clear_msg_status]
@@ -109,12 +120,10 @@ proc ::wmdock::showhide {} {
     }
 }
 
-proc ::wmdock::dock_balloon {ev x y} {
+proc ::wmdock::balloon {} {
     variable balloon_msg
 
-    if {![winfo exists .icon]} return
-
-    balloon::default_balloon .icon $ev $x $y $balloon_msg
+    return [list .icon $balloon_msg]
 }
 
 proc ::wmdock::create_dock {} {
@@ -134,10 +143,7 @@ proc ::wmdock::create_dock {} {
     pack .icon.c
     
     bind .icon <3> ::wmdock::showhide
-    
-    bind .icon <Any-Enter>  [list ::wmdock::dock_balloon enter %X %Y]
-    bind .icon <Any-Motion> [list ::wmdock::dock_balloon motion %X %Y]
-    bind .icon <Any-Leave>  [list balloon::default_balloon .icon leave  %X %Y]
+    balloon::setup .icon -command [list ::wmdock::balloon]
 }
 
 hook::add postload_hook ::wmdock::create_dock 80
