@@ -1,4 +1,4 @@
-# $Id: presence.tcl 1094 2007-04-10 08:19:45Z sergei $
+# $Id: presence.tcl 1391 2008-03-07 19:03:08Z sergei $
 
 ###############################################################################
 
@@ -603,35 +603,13 @@ proc custom_presence_menu {m connid jid} {
     $mm add command -label [::msgcat::mc "Unavailable"] \
 	-command [list send_custom_presence $jid unavailable -connection $connid]
 
-    $m add cascad -label [::msgcat::mc "Send custom presence"] -menu $mm
+    $m add cascade -label [::msgcat::mc "Send custom presence"] -menu $mm
 }
 
 hook::add chat_create_user_menu_hook custom_presence_menu 43
 hook::add roster_jid_popup_menu_hook custom_presence_menu 43
 hook::add roster_service_popup_menu_hook custom_presence_menu 43
-
-###############################################################################
-
-proc custom_conference_presence_menu {m connid jid} {
-    set mm [menu $m.custom_presence -tearoff 0]
-
-    $mm add command -label [::msgcat::mc "Available"] \
-	-command [list send_custom_presence $jid available -connection $connid]
-    $mm add command -label [::msgcat::mc "Free to chat"] \
-	-command [list send_custom_presence $jid chat -connection $connid]
-    $mm add command -label [::msgcat::mc "Away"] \
-	-command [list send_custom_presence $jid away -connection $connid]
-    $mm add command -label [::msgcat::mc "Extended away"] \
-	-command [list send_custom_presence $jid xa -connection $connid]
-    $mm add command -label [::msgcat::mc "Do not disturb"] \
-	-command [list send_custom_presence $jid dnd -connection $connid]
-    $mm add command -label [::msgcat::mc "Unavailable"] \
-	-command [list send_custom_presence $jid unavailable -connection $connid]
-
-    $m add cascad -label [::msgcat::mc "Send custom presence"] -menu $mm
-}
-
-hook::add chat_create_conference_menu_hook custom_conference_presence_menu 43
+hook::add chat_create_conference_menu_hook custom_presence_menu 43
 
 ###############################################################################
 
