@@ -1,4 +1,4 @@
-# $Id: register.tcl 1099 2007-04-12 06:44:00Z sergei $
+# $Id: register.tcl 1373 2008-02-05 19:19:06Z sergei $
 
 namespace eval register {
     set winid 0
@@ -154,7 +154,6 @@ proc register::unregister {w connid jid} {
 
 
 proc register::recv_result {w connid jid res child} {
-    global font
     variable data
 
     debugmsg register "$res $child"
@@ -168,7 +167,6 @@ proc register::recv_result {w connid jid res child} {
 	set m [message $w.error.msg \
 		       -aspect 50000 \
 		       -text [error_to_string $child] \
-		       -font $font \
 		       -pady 2m]
 	$m configure -foreground [option get $m errorForeground Message]
 	pack $m
@@ -191,9 +189,7 @@ proc register::recv_result {w connid jid res child} {
 }
 
 
-hook::add postload_hook \
-    [list browser::register_ns_handler $::NS(register) register::open \
-    -desc [list * [::msgcat::mc "Register"]]]
 hook::add postload_hook \
     [list disco::browser::register_feature_handler $::NS(register) register::open \
     -desc [list * [::msgcat::mc "Register"]]]
+
