@@ -32,7 +32,7 @@
 # liability for all claims, expenses, losses, damages and costs any user may
 # incur as a result of using, copying or modifying the Software.
 #
-# $Id: sgmlparser.tcl 1338 2007-12-30 14:46:15Z sergei $
+# $Id: sgmlparser.tcl 1465 2008-07-05 15:46:58Z sergei $
 
 package require -exact sgml 1.8
 
@@ -1010,8 +1010,28 @@ proc sgml::ParseEvent:ElementOpen {tag attr opts args} {
 	set ns [list -namespace [lindex $state(defaultNSURI) end]]
     }
 
+    # Prepend attributes with XMLNS URI
+    set attr1 {}
+    foreach {key val} $attr {
+	if {[regexp {([^:]+):(.*)$} $key discard prefix key1]} {
+	    set nsspec [lsort -dictionary -decreasing [array names namespaces $prefix,*]]
+	    if {[llength $nsspec]} {
+		set nsuri $namespaces([lindex $nsspec 0])
+		lappend attr1 $nsuri:$key1 $val
+	    } else {
+		# HACK: ignore undeclared namespace
+		# TODO: investigate it
+		#uplevel #0 $options(-errorcommand) \
+		#	[list namespaceundeclared "no namespace declared for prefix \"$prefix\" in attribute $key"]
+		lappend attr1 $key $val
+	    }
+	} else {
+	    lappend attr1 $key $val
+	}
+    }
+
     # Invoke callback
-    set code [catch {uplevel #0 $options(-elementstartcommand) [list $tag $attr] $empty $ns $nsdecls} msg]
+    set code [catch {uplevel #0 $options(-elementstartcommand) [list $tag $attr1] $empty $ns $nsdecls} msg]
     return -code $code -errorinfo $::errorInfo $msg
 }
 
